Learn R Programming

CICI (version 0.9.7)

CICI-package: Causal Inference with Continuous (Multiple Time Point) Interventions

Description

This package facilitates the estimation of counterfactual outcomes for multiple values of continuous interventions at different time points, and allows plotting of causal dose-response curves.

It implements the standard g-methods approach using the (semi-)parametric g-formula, as described in the Schomaker et al. (2024) reference listed below. Weighted dose-response curves that address positivity violations, and are fitted via sequential g-computation, are currently only available on GitHub and are not (yet) integrated in this package.

The main function of the package is currently gformula.

Arguments

Author

Michael Schomaker

Maintainer: Michael Schomaker <michael.schomaker@stat.uni-muenchen.de>

Details

Package:CICI
Type:Package
Version:0.9.7
Date:2025-12-19
License:GPL-2
Depends:R (>= 4.0)
Imports:mgcv, glmnet, ggplot2, parallel, doParallel, foreach, doRNG, rngtools, survival
Suggests:haldensify, hal9001

References

Schomaker M, McIlleron H, Denti P, Diaz I. (2024) Causal Inference for Continuous Multiple Time Point Interventions, Statistics in Medicine, 43:5380-5400, see also https://arxiv.org/abs/2305.06645.