Learn R Programming

CICI (version 0.9.7)

print.gformula: Printing the results of a gformula object

Description

Generic S3 function to print the results of an object created with gformula.

Usage

# S3 method for gformula
print(x, ...)

Value

No return value, called for printing the results of an object of class class `gformula'.

Arguments

x

An object of class `gformula'.

...