View source: R/summary.feasible.R
| summary.feasible | R Documentation |
feasible objectDisplays the full summary of an object returned by feasible.
## S3 method for class 'feasible'
summary(object, ...)
object |
An object of class |
... |
Unused; included for S3 method compatibility. |
The method extracts the data frame stored in the "summary" attribute of the feasible object.
This data frame contains (at least) the following columns:
time: Time index t.
Strategy: Index of the intervention strategy.
Abar: The target intervention value at time t.
Feasible: Mean of the mapped feasible values for the targeted bin.
%infeasible: Proportion of observations falling below the estimated density threshold for the given Abar as targeted.
If the "summary" attribute is NULL, the method prints “No summary available.”
A data frame containing the summary if available; otherwise NULL.
feasible, plot.feasible
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.