Learn R Programming

CICI (version 0.9.7)

summary.feasible: Summarize a feasible object

Description

Displays the full summary of an object returned by feasible.

Usage

# S3 method for feasible
summary(object, ...)

Value

A data frame containing the summary if available; otherwise NULL.

Arguments

object

An object of class "feasible" as returned by feasible.

...

Unused; included for S3 method compatibility.

Details

The method extracts the data frame stored in the "summary" attribute of the feasible object. This data frame contains (at least) the following columns:

  • time: Time index t.

  • Strategy: Index of the intervention strategy.

  • Abar: The target intervention value at time t.

  • Feasible: Mean of the mapped feasible values for the targeted bin.

  • %infeasible: Proportion of observations falling below the estimated density threshold for the given Abar as targeted.

If the "summary" attribute is NULL, the method prints “No summary available.”

See Also

feasible, plot.feasible

Examples

Run this code
# see ?feasible

Run the code above in your browser using DataLab