The method extracts the data frame stored in the "summary" attribute of the feasible object.
This data frame contains (at least) the following columns:
time: Time index t.
Strategy: Index of the intervention strategy.
Abar: The target intervention value at time t.
Feasible: Mean of the mapped feasible values for the targeted bin.
%infeasible: Proportion of observations falling below the estimated density threshold for the given Abar as targeted.
If the "summary" attribute is NULL, the method prints “No summary available.”